/* "Compuslory Education and the Benefits of Schooling" */
/* Create tables and figure */

#delimit';'
set memory 3500M;
set matsize 800;
set more off;

/* Begin with reading in data directly from IPUMS extracts */

/* Read in data from each year */
use cens1960ext_aer.dta;
append using cens1970ext_aer.dta;
append using cens1980ext_aer.dta;

sum;


/* Create year of birth using age and birth quarter */
gen yob = year - age if birthqtr==1;
replace yob = year - age - 1 if birthqtr>=2&birthqtr<=4;


/* Keep only those ages 25-54 */
gen samp2554 = 1 if year==1960&yob>=1905&yob<=1934;
replace samp2554 = 1 if year==1970&yob>=1915&yob<=1944;
replace samp2554 = 1 if year==1980&yob>=1925&yob<=1954;
keep if samp2554==1;
drop samp2554;


/* Replace weeks worked categories for 1960 and 1970 */
/* using same values as in A&A */
gen weeks = wkswork1 if year==1980; /* Have actual values in 1980 */
replace weeks = 0 if year==1960&wkswork2==0; 
replace weeks = 8.5 if year==1960&wkswork2==1;
replace weeks = 21.9 if year==1960&wkswork2==2;
replace weeks = 33.2 if year==1960&wkswork2==3;
replace weeks = 42.6 if year==1960&wkswork2==4;
replace weeks = 48.3 if year==1960&wkswork2==5;
replace weeks = 51.8 if year==1960&wkswork2==6;
replace weeks = 0 if year==1970&wkswork2==0;
replace weeks = 8.4 if year==1970&wkswork2==1;
replace weeks = 21.4 if year==1970&wkswork2==2;
replace weeks = 33.1 if year==1970&wkswork2==3;
replace weeks = 42.6 if year==1970&wkswork2==4;
replace weeks = 48.3 if year==1970&wkswork2==5;
replace weeks = 51.8 if year==1970&wkswork2==6;


/* Replace wages with censored values above topcode based on A&A */
replace incwage = 20250 if incwage>13500&incwage!=.&year==1960;
replace incwage = 37275 if incwage>24850&incwage!=.&year==1970;
replace incwage = 75007.5 if incwage>50005&incwage!=.&year==1980;


/* Recode education to match A&A */
gen gradcap = 0 if higrade>=0&higrade<=3;
replace gradcap = higrade - 3 if higrade>=4&higrade<=20;
replace gradcap = 17 if higrade>=21&higrade<=23;


/* Adjust the weights for 1970 */
/* 1970 uses two 1% samples, each has a weight of 100 */
/* But since using both, have 2% for 1970 - thus need weight of 50 */
replace slwt = slwt/2 if year==1970;


/* Create the log weekly wage */
gen lnwkwage = log(incwage/weeks);

/* Create the log of the occupational score */
gen lnoccscore = log(occscore);

/* Create an indicator for male */
gen male = sex==1;

/* Creat race indicators */
gen white = race==1;
gen black = race==2;
gen othrace = race>2;

/* Limit to those born in the US but not Alaska or Hawaii */
keep if bpl>=1&bpl<=56&bpl!=2&bpl!=15;

/* Keep those currently residing in the US - not in Alaska or Hawaii */
keep if statefip>=1&statefip<=56&statefip!=2&statefip!=15;

bysort year: sum;


/* Create the yearat14 for merging on A&A laws */
/* Does not adjust for quarter of birth */
gen yearat14 = year - age + 14;


/* Rename place of birth variable to match those in the A&A dataset */
rename bpl bplg;

/* Only keep variables that will be used below */
keep serial pernum year bplg statefip age birthqtr yob gradcap slwt
     lnoccscore empstat gqtype marst yearat14 lnwkwage
     male black othrace;

sum;


/* Merge on additional datasets */

/* Merge on A&As laws which is based on year-age-1 not year of birth */
sort bplg yearat14;
merge bplg yearat14 using schooling_laws_aa.dta,
      keep(enrolage drop_age req_sch work_age work_sch ca cl);
sum enrolage drop_age req_sch work_age work_sch ca cl;

tab _merge;
keep if _merge==1|_merge==3;
sum _merge enrolage drop_age req_sch work_age work_sch ca cl;
drop _merge;


/* Merge on cumulative schooling laws created by looping through ages 6-17 */
sort bplg yob;
merge bplg yob using schooling_laws_sy.dta,
      keep(numlawyears);

tab _merge;
keep if _merge==1|_merge==3;
drop _merge;


/* Now merge on quality variables from Card and Krueger */
sort bplg yob;
merge bplg yob using ck_school_quality_revised.dta,
      keep(pupilt term reltwage);

tab _merge;
keep if _merge==1|_merge==3;
drop _merge;

sum bplg yob pupilt term reltwage;


/* Create schooling law measures */
gen cl7 = cl==7;
gen cl8 = cl==8;
gen cl9 = cl>=9;
sum cl*;
tab cl;

gen ca9 = ca==9;
gen ca10 = ca==10;
gen ca11 = ca>=11;
sum ca*;
tab ca;


/* Create a corrected CA variable */
gen corr_ca = 0 if enrolage==.|enrolage==0;
replace corr_ca = drop_age - enrolage if enrolage!=.&(req_sch==.|req_sch==0);
replace corr_ca = min(drop_age - enrolage,req_sch)
        if enrolage!=.&req_sch>0&req_sch!=.;

gen corr_ca8 = corr_ca==8;
gen corr_ca9 = corr_ca==9;
gen corr_ca10 = corr_ca>=10;
sum corr_ca*;
tab corr_ca;
tab corr_ca ca;


/* Construct Required Schooling instrument */
tab numlawyears [aweight=slwt];
gen ny7 = numlawyears==7 if numlawyears!=.;
gen ny8 = numlawyears==8 if numlawyears!=.;
gen ny9 = numlawyears>=9 if numlawyears!=.;


/* Create additional variables */

/* Need year by state of birth for clustering */
gen yob_bplg = (yob-1900)*100 + bplg;

/* Create year and age variables */
gen byte census70 = year==1970;
gen byte census80 = year==1980;
gen age2 = age^2;
gen age3 = age^3;
gen age4 = age^4;

/* Create state dummies for state of birth and currrent state of residence */ 
/* NOT THROUGH 56, just 55 - Make Wyoming the excluded state */
/* Also create year of birth dummies */
quietly for num 1/55: gen byte sobX = bplg==X;
quietly for num 5/9: gen byte yob0X = yob==1900+X;
quietly for num 10/53: gen byte yobX = yob==1900+X;

/* Then drop missing state data */
/* SOB - Can only use those born in 48 continguous states+DC */
/* In addition, need to drop NON-fips codes state numbers */
/* As seen in summarize command, these SOB variables have zeroes */
sum sob2 sob15; /* Alaska and Hawaii */
sum sob3 sob7 sob14 sob43 sob52; /* NON-states - all with no values */
drop sob2 sob15 sob3 sob7 sob14 sob43 sob52;


/* Generate Southern state of birth */
gen southern_born =
sob10==1|sob11==1|sob12==1|sob13==1|sob24==1|sob37==1|sob45==1|sob51==1|sob54==1|sob1==1|sob21==1|sob28==1|sob47==1|sob5==1|sob22==1|sob40==1|sob48==1;

/* Generate Midwest state of birth */
gen midwestern_born = sob18==1|sob17==1|sob26==1|sob39==1|sob55==1|sob19==1|sob20==1|sob27==1|sob29==1|sob31==1|sob38==1|sob46==1;

/* Generate Northeast state of birth */
gen northeastern_born = sob9==1|sob23==1|sob25==1|sob33==1|sob44==1|sob50==1|sob34==1|sob36==1|sob42==1;

/* Generate West state of birth */
/* NO SOB56 - So instead make it everyone not assigned to another region */
gen western_born = southern_born==0&midwestern_born==0&northeastern_born==0;


/* Generate a single region of birth variable */
gen region = 1 if northeastern_born==1;
replace region = 2 if southern_born==1;
replace region = 3 if midwestern_born==1;
replace region = 4 if western_born==1;
tab region;


/* Include a separate trend for being born in each of the regions - except the Northeast */
/* Need to do separately by region so that list works properly */
quietly for var yob05-yob53 : gen byte south_X = southern_born*X;
quietly for var yob05-yob53 : gen byte midwest_X = midwestern_born*X;
quietly for var yob05-yob53 : gen byte west_X = western_born*X;


/* Only use Whites in Tables and Figure */
keep if black==0&othrace==0;
gen cons_p = sqrt(slwt)
save replications.dta, replace
s

#delimit';'
/* TABLE 1 ESTIMATES */
global inst_set "ny7 ny8 ny9";
global inst_set_adj "ny7_adj ny8_adj ny9_adj";

/* EXAMINE WHITE MALES AGES 40-49 IN COLUMNS 1-2 */
preserve;
keep if male==1;
keep if lnwkwage!=.;
keep if (year==1960&yob>=1910&yob<=1919)|
        (year==1970&yob>=1920&yob<=1929)|
        (year==1980&yob>=1930&yob<=1939);


/* Column 1 - LOG WEEKLY WAGE - BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "yob10-yob38 sob1-sob55";
global riv_lower_bound ".050";
global riv_upper_bound ".140";
global riv_grid ".001";

global specid = 157;
do "${progdir}regs_include_replicate.do";


/* Column 2 - LOG WEEKLY WAGE - ADD FOUR REGION-YOB DUMMIES TO BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "yob10-yob38 sob1-sob55 south_yob10-south_yob38 midwest_yob10-midwest_yob38 west_yob10-west_yob38";
global riv_lower_bound "-.200";
global riv_upper_bound ".090";
global riv_grid ".001";

global specid = 158;
do "${progdir}regs_include_replicate.do";



/* EXAMINE WHITE MALES AGES 25-54 IN COLUMNS 3-4 */
restore;
preserve;
keep if male==1;
keep if lnwkwage!=.;


/* Column 3 - LOG WEEKLY WAGE - BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound ".070";
global riv_upper_bound ".130";
global riv_grid ".001";

global specid = 159;
do "${progdir}regs_include_replicate.do";


/* Column 4 - LOG WEEKLY WAGE - ADD FOUR REGION-YOB DUMMIES TO BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.080";
global riv_upper_bound ".040";
global riv_grid ".001";

global specid = 160;
do "${progdir}regs_include_replicate.do";



/* EXAMINE WHITE MALES AND FEMALES AGES 25-54 IN COLUMNS 5-6 */
restore;

#delimit';'
preserve;
keep if lnwkwage!=.;


/* Column 5 - LOG WEEKLY WAGE - BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 male census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound ".070";
global riv_upper_bound ".140";
global riv_grid ".001";

global specid = 177;
do "${progdir}regs_include_replicate.do";


/* Column 6 - LOG WEEKLY WAGE - ADD FOUR REGION-YOB DUMMIES TO BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 male census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.070";
global riv_upper_bound ".050";
global riv_grid ".001";

global specid = 178;
do "${progdir}regs_include_replicate.do";




/* EXAMINE WHITE MALES AND FEMALES AGES 25-54 BY REGION IN COLUMNS 7-8 */

/* Column 7 - LOG WEEKLY WAGE - NON-SOUTHERN BORN - BASELINE MODEL */
restore;
preserve;
keep if lnwkwage!=.;
keep if southern_born==0;

/* Drop all of the southern state of birth dummies */
sum sob10 sob11 sob12 sob13 sob24 sob37 sob45 sob51 sob54
    sob1 sob21 sob28 sob47 sob5 sob22 sob40 sob48;
drop sob10 sob11 sob12 sob13 sob24 sob37 sob45 sob51 sob54
     sob1 sob21 sob28 sob47 sob5 sob22 sob40 sob48;
sum sob*;

global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 male census70 census80 yob05-yob53 sob4-sob55";
                     /* Start with Arizona (fips=4) since Alabama is in South*/
global riv_lower_bound "-.040";
global riv_upper_bound ".010";
global riv_grid ".001";

global specid = 179;
do "${progdir}regs_include_replicate.do";


/* Column 8 - LOG WEEKLY WAGE - SOUTHERN BORN - BASELINE MODEL */
restore;
preserve;
keep if lnwkwage!=.;
keep if southern_born==1;

sum sob10 sob11 sob12 sob13 sob24 sob37 sob45 sob51 sob54
    sob1 sob21 sob28 sob47 sob5 sob22 sob40 sob48;
sum sob*;

global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 male census70 census80 yob05-yob53
                     sob10 sob11 sob12 sob13 sob24 sob37 sob45 sob51 sob54
                     sob21 sob28 sob47 sob5 sob22 sob40 sob48";
                     /* Alabama (fips=1) is the excluded state */

global riv_lower_bound "-.120";
global riv_upper_bound ".100";
global riv_grid ".001";

global specid = 180;
do "${progdir}regs_include_replicate.do";




/* TABLE 2 ESTIMATES */
global inst_set "ny7 ny8 ny9";
global inst_set_adj "ny7_adj ny8_adj ny9_adj";


/* Row 1 - LOG WEEKLY WAGE */
restore;
preserve;
keep if male==1;
keep if lnwkwage!=.;
sum year lnwkwage [weight=slwt];

/* Row 1, Columns 1 and 2 - LOG WEEKLY WAGE - BASELINE MODEL */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound ".070";
global riv_upper_bound ".130";
global riv_grid ".001";

*do "${progdir}regs_include.do"; // same as Table 1 (3)


/* Row 1, Column 3 - LOG WEEKLY WAGE WITH FOUR REGION-YOB DUMMIES */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.080";
global riv_upper_bound ".040";
global riv_grid ".001";

*do "${progdir}regs_include.do"; // same as Table 1 (4)


/* Row 1, Column 4 - LOG WEEKLY WAGE WITH SCHOOL QUALITY */
global outcomev "lnwkwage";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.030";
global riv_upper_bound ".070";
global riv_grid ".001";

global specid = 171;
do "${progdir}regs_include_replicate.do";


/* Row 2 - LOG OCCUPATIONAL SCORE */
restore;
preserve;
keep if male==1;
keep if lnwkwage!=.;
keep if lnoccscore!=.;
sum year lnwkwage lnoccscore [weight=slwt];

/* Row 2, Columns 1 and 2 - LOG OCCUPATIONAL SCORE - BASELINE MODEL */
global outcomev "lnoccscore";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound ".000";
global riv_upper_bound ".040";
global riv_grid ".001";

global specid = 161;
do "${progdir}regs_include_replicate.do";


/* Row 2, Column 3 - LOG OCCUPATIONAL SCORE WITH FOUR REGION-YOB DUMMIES */
global outcomev "lnoccscore";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.030";
global riv_upper_bound ".050";
global riv_grid ".001";

global specid = 162;
do "${progdir}regs_include_replicate.do";


/* Row 2, Column 4 - LOG OCCUPATIONAL SCORE WITH SCHOOL QUALITY */
global outcomev "lnoccscore";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.020";
global riv_upper_bound ".040";
global riv_grid ".001";

global specid = 172;
do "${progdir}regs_include_replicate.do";


/* Row 3 - UNEMPLOYED */
restore;
preserve;
keep if male==1;
keep if empstat!=.;
gen unemployed = empstat==2;
sum year lnwkwage empstat unemployed [weight=slwt];


/* Row 3, Columns 1 and 2 - UNEMPLOYED - BASELINE MODEL */
global outcomev "unemployed";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.015";
global riv_upper_bound ".000";
global riv_grid ".0001";

global specid = 163;
do "${progdir}regs_include_replicate.do";

/* Row 3, Column 3 - UNEMPLOYED WITH FOUR REGION-YOB DUMMIES */
global outcomev "unemployed";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.010";
global riv_upper_bound ".020";
global riv_grid ".0001";

global specid = 164;
do "${progdir}regs_include_replicate.do";


/* Row 3, Column 4 - UNEMPLOYED WITH SCHOOL QUALITY */
global outcomev "unemployed";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound ".000";
global riv_upper_bound ".030";
global riv_grid ".0001";

global specid = 173;
do "${progdir}regs_include_replicate.do";



/* Row 4 - DIVORCED */
restore;
preserve;
keep if male==1;
keep if marst!=.;
gen divorced = marst==4;
sum year lnwkwage marst divorced [weight=slwt];


/* Row 4, Columns 1 and 2 - DIVORCED - BASELINE MODEL */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.015";
global riv_upper_bound ".005";
global riv_grid ".0001";

global specid = 165;
do "${progdir}regs_include_replicate.do";


/* Row 4, Column 3 - DIVORCED WITH FOUR REGION-YOB DUMMIES */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.030";
global riv_upper_bound ".020";
global riv_grid ".0001";

global specid = 166;
do "${progdir}regs_include_replicate.do";


/* Row 4, Column 4 - DIVORCED WITH SCHOOL QUALITY */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.040";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 174;
do "${progdir}regs_include_replicate.do";



/* Row 5 - IN MENTAL */
restore;
preserve;
keep if male==1;
keep if gqtype!=.;
gen inmental = gqtype==3;
sum year lnwkwage gqtype inmental [weight=slwt];


/* Row 5, Columns 1 and 2 - IN MENTAL - BASELINE MODEL */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 167;
do "${progdir}regs_include_replicate.do";


/* Row 5, Column 3 - IN MENTAL WITH FOUR REGION-YOB DUMMIES */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 168;
do "${progdir}regs_include_replicate.do";


/* Row 5, Column 4 - IN MENTAL WITH SCHOOL QUALITY */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 175;
do "${progdir}regs_include_replicate.do";


/* Row 6 - IN JAIL */
restore;
preserve;
keep if male==1;
keep if gqtype!=.;
gen injail = gqtype==2;
sum year lnwkwage gqtype injail [weight=slwt];


/* Row 6, Columns 1 and 2 - IN JAIL - BASELINE MODEL */
global outcomev "injail";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 169;
do "${progdir}regs_include_replicate.do";


/* Row 6, Column 3 - IN JAIL WITH FOUR REGION-YOB DUMMIES */
global outcomev "injail";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 170;
do "${progdir}regs_include_replicate.do";


/* Row 6, Column 4 - IN JAIL WITH SCHOOL QUALITY */
global outcomev "injail";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 176;
do "${progdir}regs_include_replicate.do";



/* Row 7 - DIVORCED - WHITE FEMALES */
restore;
preserve;
keep if male==0;
keep if marst!=.;
gen divorced = marst==4;
sum year lnwkwage marst divorced [weight=slwt];


/* Row 7, Columns 1 and 2 - DIVORCED - BASELINE MODEL */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 181;
do "${progdir}regs_include_replicate.do";


/* Row 7, Column 3 - DIVORCED WITH FOUR REGION-YOB DUMMIES */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.010";
global riv_upper_bound ".020";
global riv_grid ".0001";

global specid = 183;
do "${progdir}regs_include_replicate.do";



/* Row 7, Column 4 - DIVORCED WITH SCHOOL QUALITY */
global outcomev "divorced";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.010";
global riv_upper_bound ".010";
global riv_grid ".0001";

global specid = 185;
do "${progdir}regs_include_replicate.do";



/* Row 8 - IN MENTAL - WHITE FEMALES */
restore;
preserve;
keep if male==0;
keep if gqtype!=.;
gen inmental = gqtype==3;
sum year lnwkwage gqtype inmental [weight=slwt];


/* Row 8, Columns 1 and 2 - IN MENTAL - BASELINE MODEL */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55";
global riv_lower_bound "-.003";
global riv_upper_bound ".003";
global riv_grid ".0001";

global specid = 182;
do "${progdir}regs_include_replicate.do";


/* Row 8, Column 3 - IN MENTAL WITH FOUR REGION-YOB DUMMIES */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 south_yob05-south_yob53 midwest_yob05-midwest_yob53 west_yob05-west_yob53";
global riv_lower_bound "-.004";
global riv_upper_bound ".004";
global riv_grid ".0001";

global specid = 184;
do "${progdir}regs_include_replicate.do";



/* Row 8, Column 4 - IN MENTAL WITH SCHOOL QUALITY */
global outcomev "inmental";
global control_vars "age age2 age3 age4 census70 census80 yob05-yob53 sob1-sob55 pupilt term reltwage";
global riv_lower_bound "-.003";
global riv_upper_bound ".003";
global riv_grid ".0001";

global specid = 186;
do "${progdir}regs_include_replicate.do";


 
 
